<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>Account</name>
    <message>
        <location filename="../../plugins/accountbaseplugin/constants.h" line="320"/>
        <source>Account book</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/constants.h" line="321"/>
        <source>Revenues</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/constants.h" line="322"/>
        <source>Expenses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/constants.h" line="324"/>
        <source>Cash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/constants.h" line="325"/>
        <source>Cheques</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/constants.h" line="326"/>
        <source>VISA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/constants.h" line="327"/>
        <source>Money</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/constants.h" line="328"/>
        <source>Due</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/constants.h" line="329"/>
        <source>Insurance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/constants.h" line="330"/>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountDB::AccountBase</name>
    <message>
        <location filename="../../plugins/accountbaseplugin/accountbase.cpp" line="639"/>
        <location filename="../../plugins/accountbaseplugin/accountbase.cpp" line="647"/>
        <location filename="../../plugins/accountbaseplugin/accountbase.cpp" line="653"/>
        <source>Please contact dev team.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountDB::AccountBasePlugin</name>
    <message>
        <location filename="../../plugins/accountbaseplugin/accountbaseplugin.cpp" line="78"/>
        <source>Initializing accountancy plugin...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountDB::ActsModel</name>
    <message>
        <location filename="../../plugins/accountbaseplugin/actsmodel.cpp" line="180"/>
        <source>Comments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/actsmodel.cpp" line="181"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountDB::AmountModel</name>
    <message>
        <location filename="../../plugins/accountbaseplugin/amountmodel.cpp" line="99"/>
        <source>Cash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/amountmodel.cpp" line="100"/>
        <source>Visa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/amountmodel.cpp" line="101"/>
        <source>Cheque</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/amountmodel.cpp" line="102"/>
        <source>Banking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/amountmodel.cpp" line="103"/>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/amountmodel.cpp" line="104"/>
        <source>Du</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/amountmodel.cpp" line="108"/>
        <source>Value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/accountbaseplugin/amountmodel.cpp" line="109"/>
        <source>Currency</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
